<?php
$path = "images";

// Image Resize
function image_resize($src, $w, $h) {
    $img = imagecreatefromjpeg($src);
    $oldw = imagesx($img);
    $oldh = imagesy($img);
    $template = imagecreatetruecolor($w, $h);
    imagecopyresampled($template, $img, 0, 0, 0, 0, $w, $h, $oldw, $oldh);
    return $template;
}

imagejpeg(image_resize("$path/pic1.jpg", 300, 200), "$path/pic1-resize.jpg");

// Image Crop
function image_crop($src, $x, $y, $w, $h) {
    $img = imagecreatefromjpeg($src);
    $template = imagecreatetruecolor($w, $h);
    imagecopyresampled($template, $img, 0, 0, $x, $y, $w, $h, $w, $h);
    return $template;
}

imagejpeg(image_crop("$path/pic1.jpg", 80, 110, 250, 210), "$path/pic1-crop.jpg");

// Image Convert
function image_conv_png($src, $dst, $quality) {
    $data = file_get_contents($src);
    $img = imagecreatefromstring($data);
    imagepng($img, $dst);
}

image_conv_png("$path/pic1.jpg", "$path/pic1-png.png", 50);

// Image Filter
function image_filter($src, $effect) {
    $img = imagecreatefromjpeg($src);
    imagefilter($img, $effect);
    return $img;
}

imagejpeg(image_filter("$path/pic1.jpg", IMG_FILTER_EMBOSS), "$path/pic1-filter.jpg");

// Image Water Mark
function image_watermark($src, $dst, $stamp_x, $stamp_y){
    $fontfile = dirname(__FILE__) . "/arial.ttf";
    $text = "Easy Code Share";
    
    $stamp_w = 300;
    $stamp_h = 60;
    $stamp = imagecreatetruecolor($stamp_w, $stamp_h);
    
    $white = imagecolorallocate($stamp, 255, 255, 255);
    $grey = imagecolorallocate($stamp, 128, 128, 128);
    imagefilledrectangle($stamp, 0, 0, 300, $stamp_h, $white); // create rectangle
    $angle = -4;
    $fsize = 26; // font size
    $font_x = 10; 
    $font_y = 30;
    // add shadow
    imagettftext($stamp, $fsize, $angle, $font_x+1, $font_y+1, $grey, $fontfile, $text); 
    // add text
    imagettftext($stamp, $fsize, $angle, $font_x, $font_y, $white, $fontfile, $text); 
    
    // merge image and stamp
    $img = imagecreatefromjpeg($src);
    $pct = 50;
    imagecopymerge($img, $stamp, $stamp_x, $stamp_y, 0, 0, $stamp_w, $stamp_h, $pct); 
    imagejpeg($img, $dst);
}    

image_watermark("$path/pic1.jpg", "$path/pic1-watermark.jpg", 150, 100);

?>
<!DOCTYPE html>
<html>
<head>
<title>Image Processing</title>
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
</script> 
<style>
p { margin-top: 30px; font-size: 1.5em; color: blue; }
</style>
</head>
<body>
<p>Image Resize</p>
<img src="<?=$path?>/pic1.jpg">
<img src="<?=$path?>/pic1-resize.jpg">

<p>Image Crop</p>
<img src="<?=$path?>/pic1.jpg">
<img src="<?=$path?>/pic1-crop.jpg">

<p>Image Convert to PNG</p>
<img src="<?=$path?>/pic1-png.png">

<p>Image Filter</p>
<img src="<?=$path?>/pic1-filter.jpg">

<p>Image Watermark</p>
<img src="<?=$path?>/pic1-watermark.jpg">
</body>
</html>
